#!/usr/bin/env python
# coding: utf-8
# Copyright (c) 2015 Nagarjuna Kumarappan
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# Author: Nagarjuna Kumarappan <nagarjuna.412@gmail.com>


# imports
from plumbum import local, FG
import tempfile
import os
import sys

# constants
FZF_URL = "https://github.com/junegunn/fzf"
CURRENT_DIR = os.path.dirname(os.path.realpath(__file__))

#VERSION = open(CURRENT_DIR+'/VERSION').read().strip('\n').split('.')


class FzfPrompt:

    def __init__(self):
        self.sh = local['sh']

        # check fzf
        try:
            self.fzf = local['fzf']
        except:
            raise SystemError(
                "Cannot find 'fzf' installed on PATH. ( {0} )".format(FZF_URL))

    def prompt(self, choices=None, fzf_options=""):

        # convert lists to strings [ 1, 2, 3 ] => "1\n2\n3"
        choices_str = '\n'.join(map(str, choices))

        selection = []

        with tempfile.NamedTemporaryFile() as input_file:
            with tempfile.NamedTemporaryFile() as output_file:

                # create an temp file with list entries as lines
                input_file.write(choices_str.encode())
                input_file.flush()

                self.sh['-c', CURRENT_DIR+"/filefzf.sh {0} {1} {2}".format(
                    input_file.name, output_file.name, fzf_options)] & FG

                # get selected options
                with open(output_file.name) as f:
                    for line in f:
                        selection.append(line.strip('\n'))

        return selection



#!/usr/bin/env python3

# Copyright (c) 2020, Suzuki Taisei.
# All rights reserved.
#
# $Id: kg_lib.py,v 1.32 2020/03/25 07:50:31 suzuki

from pyfzf.pyfzf import FzfPrompt
import sys
import time
from selenium import webdriver
from selenium.webdriver.chrome.options import Options

fzf = FzfPrompt()


class Driver(object):
    def __init__(self):
        option = Options()
        option.add_argument('--headless')
        self.driver = webdriver.Chrome(options=option)

    def all_operate(self):
        self.driver_operate()
        self.switch_window()
        self.printing()
        self.quiting()

    def driver_operate(self):
        self.driver.get('https://library.kwansei.ac.jp/')
        self.driver.find_element_by_xpath(
            "//*[@id='words']").send_keys(self.inputs())
        self.driver.find_element_by_xpath(
            "/html/body/div[1]/div/div[2]/div[1]/div/ul[2]/li[1]/form/input[3]").click()
        time.sleep(1)

    def inputs(self):
        return input("choose book title or word -> ")

    def switch_window(self):
        windows = self.driver.window_handles
        self.driver.switch_to.window(windows[-1])
        time.sleep(2)

    def printing(self):
        elements = self.driver.find_elements_by_class_name("opac_book_title")
        x = fzf.prompt([element.text for element in elements])
        print(x)

    def quiting(self):
        self.driver.quit()
        sys.exit()


def main():
    driver = Driver()
    driver.all_operate()


main()



#!/usr/bin/env python3
from setuptools import setup, find_packages

setup(
    name="kg_lib",
    version="0.0.1",
    packages=find_packages(),
    include_package_data=False,
    install_requires=[
        "selenium",
        "plumbum",
    ],

    entry_points="""
    [console_scripts]
    kg_lib = kg_lib:main
"""
)
